@@ -247,6 +247,11 @@
 ;; V1.53 27Nov2003 Peter S Galbraith <psg@debian.org>
 ;;  - Add menu entry for "Archived Bugs for this package" and for
 ;;    "Developer Page for This Package".  Create debian-bug-web-developer-page.
+;; V1.54 02Aug2004 Peter S Galbraith <psg@debian.org>
+;;  - Add RFH tag to wnpp.
+;; V1.54 11Nov2004 Camm Maguire <camm@enhanced.com>
+;;  - debian-bug:  Add "--list-cc=none" to call to reportbug after changes
+;;    in new version of reportbug. (Closes: #280780)
 ;; ----------------------------------------------------------------------------
 
 ;;; Todo (Peter's list):
@@ -549,6 +554,7 @@ This can be removed at some point since `bug' is not released in sarge."
     (save-excursion
       (call-process "reportbug" nil '(t t) nil
 		    "--template" "-T" "none" "-s" "none" "-S" "normal" "-b"
+                    "--list-cc=none"
                     "-q" package)
       (debian-bug--set-severity severity))
     ;; delete the mail headers, leaving only the BTS pseudo-headers
@@ -654,14 +660,16 @@ Reportbug may have sent an empty report!")))
   '(("Intent to Package [ITP]" . "ITP")
     ("Orphaned [O]". "O")
     ("Request for Adoption [RFA]" . "RFA")
-    ("Request For Package [RFP]" . "RFP"))
+    ("Request For Package [RFP]" . "RFP")
+    ("Request For Help [RFH]" . "RFH"))
   "Alist of WNPP possible bug reports.")
 
 (defvar debian-bug-wnpp-severities
   '(("ITP" . "wishlist")
     ("O". "normal")
     ("RFA" . "normal")
-    ("RFP" . "wishlist"))
+    ("RFP" . "wishlist")
+    ("RFH" . "normal"))
   "Bug severeties for each WNPP bug type.")
 
 ;;;###autoload
